@@ -231,7 +231,7 @@ class TestPropertyFieldConversion:
         assert field.required is False
 
     def test_convert_autoincrement(self, models, converter):
-        prop = models.Course.__mapper__.get_property("id")
+        prop = models.Course.__mapper__.attrs.get("id")
         field = converter.property2field(prop)
         assert field.required is False
 
@@ -241,7 +241,7 @@ class TestPropertyFieldConversion:
         Such properties should be marked as dump_only, and the type should be properly
         inferred.
         """
-        prop = models.Student.__mapper__.get_property("course_count")
+        prop = models.Student.__mapper__.attrs.get("course_count")
         field = converter.property2field(prop)
         assert type(field) is fields.Integer
         assert field.dump_only is True
@@ -250,7 +250,7 @@ class TestPropertyFieldConversion:
         """
         Tests handling of column properties that do not derive directly from Column
         """
-        prop = models.Seminar.__mapper__.get_property("label")
+        prop = models.Seminar.__mapper__.attrs.get("label")
         field = converter.property2field(prop)
         assert type(field) is fields.String
         assert field.dump_only is True
@@ -313,6 +313,22 @@ class TestFieldFor:
         field = field_for(models.Student, "full_name", field_class=fields.Date)
         assert type(field) == fields.Date
 
+    def test_related_initialization_warning(self, models, session):
+        with pytest.warns(
+            DeprecationWarning,
+            match="column` parameter is deprecated and will be removed in future releases. Use `columns` instead.",
+        ):
+            Related(column=[])
+
+    def test_related_initialization_with_columns(self, models, session):
+        ret = Related(columns=["TestCol"])
+        assert len(ret.columns) == 1
+        assert ret.columns[0] == "TestCol"
+        ret = Related(columns="TestCol")
+        assert isinstance(ret.columns, list)
+        assert len(ret.columns) == 1
+        assert ret.columns[0] == "TestCol"
+
     def test_field_for_can_override_validators(self, models, session):
         field = field_for(
             models.Student, "full_name", validate=[validate.Length(max=20)]
